using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace rssfe_DVBT_Coder_Example
{
    public partial class rssfe_dvbt_example : Form
    {
        rssfe m_Driver = null;
        public rssfe_dvbt_example()
        {
            InitializeComponent();
        }

        private void rssfe_dvbt_example_Load(object sender, EventArgs e)
        {
            Constellation.SelectedIndex = 0;
            FFTMode.SelectedIndex = 0;
            
            InputHP.SelectedIndex = 0;
            CodeRateHP.SelectedIndex = 0;
            TestSignalHP.SelectedIndex = 0;
            SourceHP.SelectedIndex = 0;
            
            InputLP.SelectedIndex = 1;
            CodeRateLP.SelectedIndex = 0;
            TestSignalLP.SelectedIndex = 0;
            SourceLP.SelectedIndex = 0;
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            if (MessageBox.Show("Are you sure you want to exit?", "Exit?", MessageBoxButtons.YesNo) == DialogResult.Yes)
            {
                if (m_Driver != null)
                    m_Driver.Dispose();
                Close();
            }
        }

        private void Apply_Click(object sender, EventArgs e)
        {
            try
            {
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
                if (m_Driver == null)
                    m_Driver = new rssfe(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);

                m_Driver.systemDisplayUpdate(true);

                m_Driver.confDVBTInputSignal(rssfeConstants.PriorityHigh, SourceHP.SelectedIndex, InputHP.SelectedIndex, StuffingHP.Checked);

                int hierarchical;
                int constellation;
                switch (Constellation.SelectedIndex)
                {
                    case 0:
                    case 1:
                    case 2:
                        hierarchical=rssfeConstants.IqcDvbtHierNone;
                        constellation=Constellation.SelectedIndex;
                        break;
                    case 3:
                    case 4:
                    case 5:
                        hierarchical=Constellation.SelectedIndex - 2;
                        constellation=rssfeConstants.IqcConst16qam;
                        break;
                    default:
                        hierarchical=Constellation.SelectedIndex - 5;
                        constellation=rssfeConstants.IqcConst64qam;
                        break;
                }

                m_Driver.confDVBTCoding(rssfeConstants.IqcDvbtChbw6, FFTMode.SelectedIndex, rssfeConstants.IqcDvbtGuar14, hierarchical, constellation);
                m_Driver.confDVBTCodeRate(rssfeConstants.PriorityHigh, CodeRateHP.SelectedIndex);
                m_Driver.confDVBTTestSignal(rssfeConstants.PriorityHigh, TestSignalHP.SelectedIndex);

                if (hierarchical == rssfeConstants.IqcDvbtHierA1)
                {
                    m_Driver.confDVBTInputSignal(rssfeConstants.PriorityLow, SourceLP.SelectedIndex, InputLP.SelectedIndex, StuffingLP.Checked);
                    m_Driver.confDVBTCodeRate(rssfeConstants.PriorityLow, CodeRateLP.SelectedIndex);
                    m_Driver.confDVBTTestSignal(rssfeConstants.PriorityLow, TestSignalLP.SelectedIndex);
                }
                m_Driver.confTxModulation(ModulationState.Checked, rssfeConstants.DmSourceDtv, rssfeConstants.DmStandardDvbt, rssfeConstants.DmSpecPolarNorm);
                m_Driver.confDVBHCoding(DVBHState.Checked, rssfeConstants.IqcDvbtSymbNat);

                m_Driver.confTxFreq(decimal.ToDouble(RFFreq.Value));
                m_Driver.confTxLevel(decimal.ToDouble(RFLevel.Value), RFState.Checked, 20.0, rssfeConstants.RfoutAmodeAuto, rssfeConstants.PowLevDbm);

                System.Windows.Forms.Cursor.Current = Cursors.Default;
            }
            catch (Exception ex)
            {
                String message;

                message = "Instrument Status Error: ";
                message += ex.Message;
                MessageBox.Show(message);
            }
        }
    }
}